Module options

Module options 

Modules

audio
screenshare
video
video43

Structs

AudioEncoding
AudioPreset
FrameMetadataFeatures
TrackPublishOptions
VideoEncoding
VideoPreset
VideoResolution

Enums

DegradationPreference
Controls how the encoder degrades quality when bandwidth is constrained.
VideoCodec
VideoEncoderBackend
Preferred backend for video encoding when publishing a video track. Preferred backend for video encoding on an RtpSender.

Functions

compute_appropriate_encoding
Return an appropriate VideoEncdoding for the specified resolution based on our presets
compute_default_simulcast_presets
Returns our most appropriate default presets
compute_presets_for_resolution
compute_video_encodings
Compute appropriate RtpEncodingParameters from the video resolution. TrackPublishOptions helps to find the most appropriate encodings
get_default_degradation_preference
Returns the appropriate degradation preference for a video track.
into_rtp_encodings
Presets must be ordered
landscape_aspect_ratio
spatial_layers_from_scalability_mode
Parse the number of spatial layers from an RTP scalability mode string. Standard modes start with L<N> where <N> is the spatial-layer count (e.g. “L3T3_KEY” -> 3, “L2T3” -> 2, “L1T3” -> 1).
video_layers_from_encodings
video_quality_for_rid