use livekit::prelude::*; to import livekit types
Re-exports
pub use crate::ConnectionState;pub use crate::DataPacket;pub use crate::DataPacketKind;pub use crate::Room;pub use crate::RoomError;pub use crate::RoomEvent;pub use crate::RoomOptions;pub use crate::RoomResult;pub use crate::RoomSdkOptions;pub use crate::SipDTMF;pub use crate::Transcription;pub use crate::TranscriptionSegment;
Structs
- Audio
Processing Options - Configuration options for audio processing (AEC, AGC, NS).
- Data
Track Frame - A frame published on a data track, consisting of a payload and optional metadata.
- Data
Track Info - Information about a published data track.
- Data
Track Options - Options for publishing a data track.
- Data
Track Sid - SFU-assigned identifier uniquely identifying a data track.
- Data
Track Stream - A stream of
DataTrackFrames received from aRemoteDataTrack. - Data
Track Subscribe Options - Options for subscribing to a data track.
- Local
Audio Track - Local
Participant - Local
Track Publication - Local
Video Track - Participant
Identity - Participant
Sid - Perform
RpcData - Parameters for performing an RPC call
- Platform
Audio - Platform audio device management for microphone capture and speaker playout.
- Playout
Device Id - Unique identifier for a playout (speaker) device.
- Playout
Device Info - Information about a playout (speaker) device.
- Publish
Timing Event - Timestamped native local video publish pipeline event.
- Publish
Timing Event Stream - A stream of native local video publish-pipeline timing events.
- Publishing
Layer - A simulcast layer currently configured on a local video publisher.
- Push
Frame Error - Frame could not be pushed to a data track.
- Recording
Device Id - Unique identifier for a recording (microphone) device.
- Recording
Device Info - Information about a recording (microphone) device.
- Remote
Audio Track - Remote
Data Track Pipeline Options - Track-level options that configure how the incoming-frame pipeline reassembles packets
for a
RemoteDataTrack. - Remote
Participant - Remote
Track Publication - Remote
Video Track - RoomSid
- RpcError
- Specialized error handling for RPC methods.
- RpcInvocation
Data - Data passed to method handler for incoming RPC invocations
- Subscribe
Timing Event - Timestamped native remote video subscribe pipeline event.
- Subscribe
Timing Event Stream - A stream of native remote video subscribe-pipeline timing events.
- Track
Dimension - Track
Sid
Enums
- Audio
Error - Errors that can occur during audio operations.
- Audio
Processing Type - The type of audio processing being used.
- Audio
Track - Audio
Track Feature - Connection
Quality - Data
Track Subscribe Error - Disconnect
Reason - Local
Track - Packet
Trailer Feature - Participant
- Publish
Error - An error that can occur when publishing a data track.
- Publish
Timing Stage - Stage reached by a native local video frame in the publish pipeline.
- Publishing
Layer Quality - Video quality for a publishing layer.
- Push
Frame Error Reason - Reason why a data track frame could not be pushed.
- Remote
Track - RpcError
Code - RtcAudio
Source - Audio source type for creating audio tracks.
- Stream
State - Subscribe
Timing Stage - Stage reached by a native remote video frame in the subscribe pipeline.
- Track
- Track
Kind - Track
Publication - Track
Source - Video
Track
Type Aliases
- Audio
Result - Result type for audio operations.
- Local
Data Track - Data track published by the local participant.
- Remote
Data Track - Data track published by a remote participant.