pub struct Room { /* private fields */ }Implementations
Sourceimpl Room
impl Room
pub async fn connect( url: &str, token: &str, options: RoomOptions, ) -> RoomResult<(Self, UnboundedReceiver<RoomEvent>)>
pub async fn close(&self) -> RoomResult<()>
pub async fn close_with_reason( &self, reason: DisconnectReason, ) -> RoomResult<()>
pub async fn simulate_scenario( &self, scenario: SimulateScenario, ) -> Result<(), EngineError>
pub async fn get_stats(&self) -> Result<SessionStats, EngineError>
pub fn subscribe(&self) -> UnboundedReceiver<RoomEvent>
pub async fn sid(&self) -> RoomSid
pub fn maybe_sid(&self) -> Option<RoomSid>
pub fn name(&self) -> String
pub fn metadata(&self) -> String
pub fn local_participant(&self) -> LocalParticipant
pub fn connection_state(&self) -> ConnectionState
Sourcepub fn is_single_peer_connection_active(&self) -> bool
pub fn is_single_peer_connection_active(&self) -> bool
Returns whether the room is currently using single peer connection signaling. If requested but not supported by server, this will be false after v0 fallback.
pub fn remote_participants( &self, ) -> HashMap<ParticipantIdentity, RemoteParticipant>
pub fn e2ee_manager(&self) -> &E2eeManager
pub fn data_channel_options(&self, kind: DataPacketKind) -> DataChannelOptions
pub fn empty_timeout(&self) -> u32
pub fn departure_timeout(&self) -> u32
pub fn max_participants(&self) -> u32
Sourcepub fn creation_time(&self) -> i64
pub fn creation_time(&self) -> i64
Returns the room creation time in milliseconds since Unix epoch.
pub fn num_participants(&self) -> u32
pub fn num_publishers(&self) -> u32
pub fn active_recording(&self) -> bool