RoomOptions

Struct RoomOptions 

#[non_exhaustive]
pub struct RoomOptions { pub auto_subscribe: bool, pub adaptive_stream: bool, pub dynacast: bool, pub e2ee: Option<E2eeOptions>, pub encryption: Option<E2eeOptions>, pub rtc_config: RtcConfiguration, pub join_retries: u32, pub sdk_options: RoomSdkOptions, pub single_peer_connection: bool, pub connect_timeout: Duration, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
auto_subscribe: booladaptive_stream: booldynacast: boole2ee: Option<E2eeOptions>
👎Deprecated: Use encryption field instead
encryption: Option<E2eeOptions>rtc_config: RtcConfigurationjoin_retries: u32sdk_options: RoomSdkOptionssingle_peer_connection: bool

Enable single peer connection mode. When true, uses one RTCPeerConnection for both publishing and subscribing instead of two separate connections. Falls back to dual peer connection if the server doesn’t support single PC.

connect_timeout: Duration

Timeout for each individual signal connection attempt