#[non_exhaustive]pub enum VideoEncoderBackend {
Auto,
Software,
Hardware,
Nvenc,
Vaapi,
VideoToolbox,
PreEncoded,
}Expand description
Preferred backend for video encoding on an RtpSender.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Use the SDK’s default encoder selection.
Software
Prefer a software encoder.
Hardware
Prefer any available hardware encoder.
Nvenc
Prefer NVIDIA NVENC when available.
Vaapi
Prefer VAAPI when available.
VideoToolbox
Prefer VideoToolbox on Apple platforms when available.
PreEncoded
Pass pre-encoded frames through without encoding raw video frames.
Implementations
Sourceimpl VideoEncoderBackend
impl VideoEncoderBackend
Sourcepub fn list_available() -> impl IntoIterator<Item = VideoEncoderBackend>
pub fn list_available() -> impl IntoIterator<Item = VideoEncoderBackend>
Returns the video encoder backends available in this process.
The result reflects the current platform, build flags, and runtime hardware capability checks.
use libwebrtc::rtp_sender::VideoEncoderBackend;
let backends: Vec<_> = VideoEncoderBackend::list_available().into_iter().collect();
assert!(backends.contains(&VideoEncoderBackend::Auto));
assert!(backends.contains(&VideoEncoderBackend::Software));Trait Implementations
Sourceimpl Clone for VideoEncoderBackend
impl Clone for VideoEncoderBackend
Sourcefn clone(&self) -> VideoEncoderBackend
fn clone(&self) -> VideoEncoderBackend
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VideoEncoderBackend
Sourceimpl Debug for VideoEncoderBackend
impl Debug for VideoEncoderBackend
Sourceimpl Default for VideoEncoderBackend
impl Default for VideoEncoderBackend
Sourcefn default() -> VideoEncoderBackend
fn default() -> VideoEncoderBackend
Returns the “default value” for a type. Read more
impl Eq for VideoEncoderBackend
Sourceimpl From<VideoEncoderBackend> for VideoEncoderBackend
impl From<VideoEncoderBackend> for VideoEncoderBackend
Sourcefn from(value: VideoEncoderBackend) -> VideoEncoderBackend
fn from(value: VideoEncoderBackend) -> VideoEncoderBackend
Converts to this type from the input type.
Sourceimpl PartialEq for VideoEncoderBackend
impl PartialEq for VideoEncoderBackend
impl StructuralPartialEq for VideoEncoderBackend